clldmpg
=======

Python library providing common functionality for CLLD apps maintained in affiliation
with the MPG.

Provides an MPG specific pyramid app scaffold and a pyramid package to be included by
a clld app.